###########################
Instrumentman documentation
###########################

*************
Instrumentman
*************

.. toctree::
    :maxdepth: 2

    overview
    changelog

************
Applications
************

.. toctree::
    :maxdepth: 2
    :caption: Applications

    about
    commands/morse
    commands/terminal
    commands/targets/index
    commands/sets/index
    commands/inclination/index
    commands/protocoltest/index
    commands/files/index
    commands/data/index
    commands/jobs/index
    commands/settings/index
